# vi:syntax=python
from rv import commands, rvtypes
from rv.commands import NeutralMenuState, CheckedMenuState

class Example_Package_ViewSwitchFrameHoldMode(rvtypes.MinorMode):

    def __init__(self):
        rvtypes.MinorMode.__init__(self)

        globalBindings = [
            ("before-graph-view-change", self.beforeViewChange, "DescriptionOfBinding"),
            ("after-graph-view-change", self.afterViewChange, "DescriptionOfBinding")
        ]
        localBindings = None

        menu = [
            ("View", [
                    ("Preseve Frame Between Views", self.togglePreserveFrame, None, self.isPreservingFrame),
            ])
        ]

        self._lastFrame = None
        self._preserving = commands.readSettings("Example_Package_ViewSwitchFrameHold", "PreserveFrame", True)

        self.init("Example_Package_ViewSwitchFrameHold", globalBindings, localBindings, menu)

    def isPreservingFrame(self):
        if self._preserving:
            return CheckedMenuState
        return NeutralMenuState

    def togglePreserveFrame(self, event=None):
        self._preserving = not self._preserving
        commands.writeSettings("Example_Package_ViewSwitchFrameHold", "PreserveFrame", self._preserving)


    def beforeViewChange(self, event):
        event.reject()

        if self._preserving:
            self._lastFrame = commands.frame()

    def afterViewChange(self, event):
        event.reject()

        if self._preserving:
            if self._lastFrame is not None:
                commands.setFrame(self._lastFrame)

        self._lastFrame = None


def createMode():
    return Example_Package_ViewSwitchFrameHoldMode()
